Learn R Programming

gerbil (version 0.1.9)

summary.gof_gerbil: Summarises a gerbil object. Printed output pertains to the goodness-of-fit tests that are applied in order to compare the distribution between observed and imputed cases for relevant variables or variable pairs.

Description

Summarises a gerbil object. Printed output pertains to the goodness-of-fit tests that are applied in order to compare the distribution between observed and imputed cases for relevant variables or variable pairs.

Usage

# S3 method for gof_gerbil
summary(object, ...)

Value

The functions print.gof_gerbil and summary.gof_gerbil display information about the cor_gerbil object. The output displayed includes: 1) the average test statistic value across all variables or variable pairs contained in the object, 2) the average p-value of all goodness-of-fit tests contained within the object, and 3) the number of tests that yieled a p-value of less than 0.05.

Arguments

object

An object of gof_gerbil class

...

Additional parameters to be passed down to inner functions.